@@ -1,10 +1,13 @@
 from math import floor, ceil
 
 import foldedleastsquares
+import logging
 import numpy as np
 from foldedleastsquares import DefaultTransitTemplateGenerator
 from lcbuilder import constants
 from scipy import stats
+from lightkurve import TessLightCurve
+from astropy.stats.sigma_clipping import sigma_clip
 
 
 class LcbuilderHelper:
@@ -37,6 +40,27 @@ class LcbuilderHelper:
             flux_err = flux_err[~mask]
         return time, flux, flux_err
 
+    @staticmethod
+    def mask_transits_dict(lc, transits_mask):
+        time, flux, flux_err = lc.time.value, lc.flux.value, lc.flux_err.value
+        for transit_mask in transits_mask:
+            logging.info('* Transit mask with P=%.2f d, T0=%.2f d, Dur=%.2f min *', transit_mask["P"],
+                         transit_mask["T0"], transit_mask["D"])
+            time, flux, flux_err = LcbuilderHelper.mask_transits(time, flux, transit_mask["P"],
+                                                                 transit_mask["D"] / 60 / 24, transit_mask["T0"])
+        lc = TessLightCurve(time=time, flux=flux, flux_err=flux_err, quality=np.zeros(len(time)))
+        return lc
+
+    @staticmethod
+    def clip_outliers(array, sigma, sigma_lower=None, sigma_upper=None):
+        mask = outlier_mask = sigma_clip(
+            data=array,
+            sigma=sigma,
+            sigma_lower=sigma_lower,
+            sigma_upper=sigma_upper,
+        ).mask
+        return array[~outlier_mask], outlier_mask
+
     @staticmethod
     def correct_epoch(mission, epoch):
         result = epoch
@@ -46,6 +70,17 @@ class LcbuilderHelper:
             result = epoch - constants.TBJD
         return result
 
+    @staticmethod
+    def normalize_mission_epoch(mission, epoch):
+        corrected_epoch = epoch
+        if mission == constants.MISSION_TESS:
+            corrected_epoch = epoch + constants.TBJD
+        elif mission == constants.MISSION_KEPLER:
+            corrected_epoch = epoch + constants.KBJD
+        elif mission == constants.MISSION_K2:
+            corrected_epoch = epoch + constants.KBJD
+        return corrected_epoch
+
     @staticmethod
     def bin(time, values, bins, values_err=None, bin_err_mode='values_std'):
         if len(time) <= bins:
@@ -91,6 +126,29 @@ class LcbuilderHelper:
                    .period_grid(star_info.radius, star_info.mass, time_span_curve, min_period,
                                 max_period, oversampling, transits_min_count, time_span_curve), oversampling
 
+    @staticmethod
+    def truncate_borders(time, flux, flux_err, min_gap_size=0.5, truncate_border=0):
+        if truncate_border <= 0:
+            return time, flux, flux_err
+        dif = time[1:] - time[:-1]
+        jumps = np.where(dif > min_gap_size)[0]
+        jumps = np.append(jumps, len(time) - 1)
+        previous_jump_index = 0
+        truncated_flux = []
+        truncated_flux_err = []
+        truncated_time = []
+        for jumpIndex in jumps:
+            time_chunk = time[previous_jump_index + 1:jumpIndex]  # ignoring first measurement as could be the last from the previous chunk
+            flux_chunk = flux[previous_jump_index + 1:jumpIndex]  # ignoring first measurement as could be the last from the previous chunk
+            flux_err_chunk = flux_err[previous_jump_index + 1:jumpIndex]  # ignoring first measurement as could be the last from the previous chunk
+            if len(time_chunk) > 0:
+                valid_indexes = np.argwhere((time_chunk > time_chunk[0] + truncate_border) & (time_chunk < time_chunk[-1] - truncate_border)).flatten()
+                truncated_time = np.append(truncated_time, time_chunk[valid_indexes])
+                truncated_flux = np.append(truncated_flux, flux_chunk[valid_indexes])
+                truncated_flux_err = np.append(truncated_flux_err, flux_err_chunk[valid_indexes])
+            previous_jump_index = jumpIndex
+        return np.array(truncated_time), np.array(truncated_flux), np.array(truncated_flux_err)
+
     @staticmethod
     def compute_cadence(time):
         cadence_array = np.diff(time) * 24 * 60 * 60
